# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify CentOS Linux and Scientific Linux as rhel
%if "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "sl" || "%{__distinit}" == "sls"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# perl_vendorlib/perl_vendorarch not defined by default prior to F-2
%{!?perl_vendorlib: %global perl_vendorlib %(eval "`perl -V:installvendorlib`"; echo $installvendorlib)}

Name:		perl-Test-Deep
Version:	0.109
Release:	1.%{__distinit}%{__distvers}
Summary:	Extremely flexible deep comparison
License:	GPL+ or Artistic
Group:		Development/Libraries
URL:		http://search.cpan.org/dist/Test-Deep/
Source0:	http://search.cpan.org/CPAN/authors/id/R/RJ/RJBS/Test-Deep-%{version}.tar.gz
Patch0:		Test-Deep-0.103-arrayeach.patch
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root-%(id -nu)
BuildArch:	noarch
BuildRequires:	perl(base)
BuildRequires:	perl(Carp)
BuildRequires:	perl(Exporter)
BuildRequires:	perl(ExtUtils::MakeMaker)
BuildRequires:	perl(overload)
BuildRequires:	perl(Scalar::Util)
BuildRequires:	perl(strict)
BuildRequires:	perl(Test::NoWarnings) >= 0.02
BuildRequires:	perl(Test::Tester) >= 0.04
BuildRequires:	perl(warnings)
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))

%description
Test::Deep gives you very flexible ways to check that the result you
got is the result you were expecting. At it's simplest it compares two
structures by going through each level, ensuring that the values
match, that arrays and hashes have the same elements and that
references are blessed into the correct class. It also handles
circular data structures without getting caught in an infinite loop.

%prep
%setup -q -n Test-Deep-%{version}

# Fix comparison against stuff other than ARRAY references with array_each()
%patch0 -p1 -b .arrayeach

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
rm -rf %{buildroot}
make pure_install PERL_INSTALL_ROOT=%{buildroot}
find %{buildroot} -type f -name .packlist -exec rm -f {} \;
find %{buildroot} -depth -type d -exec rmdir {} \; 2>/dev/null
%{_fixperms} %{buildroot}

%check
# bag.t, circular.t, and set.t hit memory issues on 5.8.0
# http://rt.perl.org/rt3/Public/Bug/Display.html?id=27630
if perl -e 'exit (($] < 5.008001) ? 0 : 1);'; then
	mv t/{bag,circular,set}.t .
fi
make test
if perl -e 'exit (($] < 5.008001) ? 0 : 1);'; then
	mv {bag,circular,set}.t t/
fi

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root,-)
%doc CHANGES README TODO
%{perl_vendorlib}/Test/
%{_mandir}/man3/Test::Deep.3pm*
%{_mandir}/man3/Test::Deep::NoTest.3pm*

%changelog
* Fri Feb 17 2012 Paul Howarth <paul@city-fan.org> 0.109-1
- Update to 0.109:
  - UNIVERSAL::isa and UNIVERAL::can are no longer called as functions: this
    was deprecated in UNIVERSAL 1.03 (CPAN RT#74760)
  - The code that builds the exporter configuration is cleaned up; more
    documentation of how it may change (for the better, without breaking stuff)
    should appear in the near future
- Add buildreqs for Perl core modules that might be dual-lived

* Tue Jun 28 2011 Paul Howarth <paul@city-fan.org> 0.108-4
- Rebuild for perl 5.14.1 in Rawhide
- Fix dist tag for CentOS 6 and Scientific Linux

* Wed Mar 23 2011 Paul Howarth <paul@city-fan.org> 0.108-2
- Skip bag.t, circular.t, and set.t on 5.8.0 (Perl RT#27630)
- Nobody else likes macros for commands
- Use %%{_fixperms} macro instead of our own chmod incantation

* Sun Oct 17 2010 Paul Howarth <paul@city-fan.org> 0.108-1
- Update to 0.108:
  - Simple (stringwise) comparison should now be much faster

* Thu Sep 30 2010 Paul Howarth <paul@city-fan.org> 0.107-1
- Update to 0.107:
  - New maintainer: Ricardo Signes (rjbs)
  - Install by default to "site" directory on perl >= 5.10.0
  - Cope with new stringification of qr{} objects in 5.13.x+
  - Fix Pod escaping errors
- This release by RJBS -> update source URL

* Wed Jun 23 2010 Paul Howarth <paul@city-fan.org> 0.106-4
- Rebuild for perl 5.12.1 in Rawhide

* Wed May 12 2010 Paul Howarth <paul@city-fan.org> 0.106-3
- Fix dist tag for RHEL-6 Beta

* Thu Nov 26 2009 Paul Howarth <paul@city-fan.org> 0.106-2
- Import from Fedora

* Fri Oct 30 2009 Stepan Kasal <skasal@redhat.com> 0.106-1
- New upstream version

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> 0.103-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> 0.103-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Wed Oct 22 2008 Lubomir Rintel <lubo.rintel@gooddata.com> 0.103-2
- Fix crash on matching array_each() against non-array

* Wed Jun 04 2008 Steven Pritchard <steve@kspei.com> 0.103-1
- Update to 0.103

* Sat May 31 2008 Steven Pritchard <steve@kspei.com> 0.102-1
- Update to 0.102

* Fri May 16 2008 Steven Pritchard <steve@kspei.com> 0.101-1
- Update to 0.101

* Sat Feb  2 2008 Tom "spot" Callaway <tcallawa@redhat.com> 0.100-2
- Rebuild for new perl

* Mon Jan 28 2008 Steven Pritchard <steve@kspei.com> 0.100-1
- Update to 0.100

* Sat Jan 12 2008 Steven Pritchard <steve@kspei.com> 0.099-1
- Update to 0.099
- Update License tag

* Tue Sep 18 2007 Steven Pritchard <steve@kspei.com> 0.098-1
- Update to 0.098

* Fri Aug 10 2007 Steven Pritchard <steve@kspei.com> 0.097-1
- Update to 0.097

* Wed Apr 18 2007 Steven Pritchard <steve@kspei.com> 0.096-2
- Use fixperms macro instead of our own chmod incantation
- BR ExtUtils::MakeMaker

* Tue Sep 26 2006 Steven Pritchard <steve@kspei.com> 0.096-1
- Update to 0.096

* Sat Sep 16 2006 Steven Pritchard <steve@kspei.com> 0.095-2
- Fix find option order

* Fri Apr 21 2006 Steven Pritchard <steve@kspei.com> 0.095-1
- Update to 0.095

* Sat Apr 08 2006 Steven Pritchard <steve@kspei.com> 0.093-1
- Specfile autogenerated by cpanspec 1.64
- Improve description
- Fix License
- Remove explicit dependency on Test::Tester and Test::NoWarnings
